@@ -1,39 +1,28 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-from context import imagy
+from imgtest import ImagyTestCase
 from imagy.config import *
 from imagy.core import *
 from imagy.store import Store
 from path import path
-import imgtest
 
 import logging
 logging.disable(logging.CRITICAL)
 
-class ImagyTestSuite(unittest.TestCase):
-    def setUp(self):
-        self.images = imgtest.images
-        self.loc = imgtest.image_loc
-        self.tmp = self.loc.parent.joinpath('imagesTEMP')
-        self.loc.copytree(self.tmp)
+class CoreTestSuite(ImagyTestCase):
+    def setup(self):
         self.s = Store()
-        self.img_locs = dict((k, self.get_imgp(v)) for k, v in self.images.items())
-
-    def get_imgp(self, img):
-        return self.tmp.joinpath(img)
-
-    def tearDown(self):
-        self.tmp.rmtree()
-
+        self.copy_images_over()
+    
     def check_image(self, img):
-        img = self.get_imgp(img)
+        img = self.img_path(img)
         sz = img.size
         compress_image(img)
         self.assertTrue(sz >= img.size)
 
     def test_store_original(self):
-        img = self.img_locs['jpg']
+        img = self.img_path('jpg')
         orig = store_original(img)
         self.assertTrue(same_file(img, orig))
         orig.remove()
@@ -50,9 +39,9 @@ class ImagyTestSuite(unittest.TestCase):
 
 def main():
     # dynamically add tests for various file formats, SO FN DRY
-    for typ, pth in imgtest.images.items():
-        fn = lambda self:self.check_image(pth)
-        setattr(ImagyTestSuite, 'test_%s' % typ, fn)
+    for typ in ImagyTestCase.image_files:
+        fn = lambda self:self.check_image(typ)
+        setattr(CoreTestSuite, 'test_%s' % typ, fn)
     unittest.main()
 
 if __name__ == '__main__':
